@@ -17,7 +17,7 @@ class TrackerConfigBase(dict):
     """
     Dictionary with default values that are defined by the subclass
 
-    The keys ``announce``, ``source`` and ``exclude`` always exist.
+    Some keys defined by this base class always exist.
     """
 
     _defaults = {
@@ -33,7 +33,7 @@ class TrackerConfigBase(dict):
             value=types.Choice(
                 value='',
                 empty_ok=True,
-                options=(client.name for client in btclients.clients()),
+                options=btclients.client_names(),
             ),
             description=('BitTorrent client to add torrent to after submission.'),
         ),
@@ -505,9 +505,14 @@ class TrackerJobsBase(abc.ABC):
     @cached_property
     def scene_check_job(self):
         """:class:`~.jobs.scene.SceneCheckJob` instance"""
+        kwargs = self.common_job_args.copy()
+        if self.options.get('is_scene') is not None:
+            kwargs['force'] = self.options.get('is_scene')
+            # Don't use cached value if the user made a choice
+            kwargs['ignore_cache'] = True
         return jobs.scene.SceneCheckJob(
             content_path=self.content_path,
-            **self.common_job_args,
+            **kwargs,
         )
 
     def make_choice_job(self, name, label, options, condition=None,
@@ -765,8 +770,8 @@ class _Howto:
                 f'{self._section}. Add Uploaded Torrents To Client (Optional)\n'
                 '\n'
                 f'   {self._section}.1 Specify which client to add uploaded torrents to.\n'
-                '       See --add-to below for a list of CLIENT_NAMEs.\n'
                 f'       $ upsies set trackers.{self._tracker_cls.name}.add-to CLIENT_NAME\n'
+                f'       Supported clients: ' + ', '.join(btclients.client_names()) + '\n'
             ),
             (
                 f'   {self._section}.2 Specify your client connection.\n'
