@@ -706,6 +706,11 @@ class BbTrackerJobs(TrackerJobsBase):
         elif 'Restored' in self.release_name.edition:
             return 'Restored'
 
+    @property
+    def release_info_open_matte(self):
+        if 'Open Matte' in self.release_name.edition:
+            return 'Open Matte'
+
     @property
     def release_info_directors_cut(self):
         if "Director's Cut" in self.release_name.edition:
@@ -785,7 +790,13 @@ class BbTrackerJobs(TrackerJobsBase):
 
         # "SxxEyy"
         elif self.is_episode_release:
-            title.append(str(self.release_name.episodes))
+            if self.release_name.date:
+                # Episodes may have a date (e.g. "2001-03-24") instead of the
+                # usual "SxxEyy" string
+                title.append(str(self.release_name.date))
+            else:
+                # Use "SxxEyy" string or default to "UNKNOWN_EPISODE"
+                title.append(str(self.release_name.episodes))
 
         info = [
             # [Source / VideoCodec / AudioCodec / Container / Resolution]
@@ -820,6 +831,7 @@ class BbTrackerJobs(TrackerJobsBase):
             self.release_info_2in1,
 
             # Features
+            self.release_info_open_matte,
             self.release_info_dual_audio,
             self.release_info_commentary,
             self.release_info_subtitles,
@@ -920,6 +932,7 @@ class BbTrackerJobs(TrackerJobsBase):
             self.release_info_2in1,
 
             # Features
+            self.release_info_open_matte,
             self.release_info_dual_audio,
             self.release_info_commentary,
             self.release_info_subtitles,
