@@ -15,48 +15,55 @@ _log = logging.getLogger(__name__)
 
 class WebDbSearchJobWidget(JobWidgetBase):
     def setup(self):
-        right_column_width = 40
+        total_width = 80
+        left_column_width = 36
+        right_column_width = total_width - left_column_width - 1
         self._widgets = {
-            'id' : widgets.TextField(width=15, style='class:dialog.search.info'),
-            'query' : widgets.InputField(
+            # First row
+            'id': widgets.TextField(width=15, style='class:dialog.search.info'),
+            'query': widgets.InputField(
                 style='class:dialog.search.query',
                 text=str(self.job.query),
                 on_accepted=self.handle_query,
             ),
-            'search_results' : _SearchResults(width=40),
-            'summary' : widgets.TextField(
+
+            # Right column
+            'search_results': _SearchResults(width=right_column_width),
+            'title_original': widgets.TextField(
                 style='class:dialog.search.info',
                 width=right_column_width,
+                height=1,
+            ),
+            'title_english': widgets.TextField(
+                style='class:dialog.search.info',
+                width=right_column_width,
+                height=1,
+            ),
+
+            # Left column
+            'summary': widgets.TextField(
+                style='class:dialog.search.info',
+                width=left_column_width,
                 height=8,
             ),
-            'title_original' : widgets.TextField(
+            'genres': widgets.TextField(
                 style='class:dialog.search.info',
-                width=right_column_width,
-                height=1,
-            ),
-            'title_english' : widgets.TextField(
-                style='class:dialog.search.info',
-                width=right_column_width,
-                height=1,
-            ),
-            'genres' : widgets.TextField(
-                style='class:dialog.search.info',
-                width=right_column_width,
+                width=left_column_width,
                 height=2,
             ),
-            'directors' : widgets.TextField(
+            'directors': widgets.TextField(
                 style='class:dialog.search.info',
-                width=right_column_width,
+                width=left_column_width,
                 height=1,
             ),
-            'cast' : widgets.TextField(
+            'cast': widgets.TextField(
                 style='class:dialog.search.info',
-                width=right_column_width,
+                width=left_column_width,
                 height=2,
             ),
-            'countries' : widgets.TextField(
+            'countries': widgets.TextField(
                 style='class:dialog.search.info',
-                width=right_column_width,
+                width=left_column_width,
                 height=1,
             ),
         }
@@ -189,8 +196,8 @@ class _SearchResults(DynamicContainer):
         self._year_width = 4
         self._type_width = 6
         self._title_width = width - self._year_width - self._type_width - 2
-        self._throbber = utils.Throbber(callback=self._throbber_callback)
-        self._throbber_string = '...'
+        self._activity_indicator = utils.ActivityIndicator(callback=self._activity_indicator_callback)
+        self._activity_indicator_string = ''
         super().__init__(
             lambda: Window(
                 content=FormattedTextControl(self._get_text_fragments, focusable=False),
@@ -202,11 +209,11 @@ class _SearchResults(DynamicContainer):
 
     @property
     def is_searching(self):
-        return self._throbber.active
+        return self._activity_indicator.active
 
     @is_searching.setter
     def is_searching(self, value):
-        self._throbber.active = bool(value)
+        self._activity_indicator.active = bool(value)
 
     @property
     def results(self):
@@ -238,13 +245,13 @@ class _SearchResults(DynamicContainer):
     def select_last(self):
         self._focused_index = len(self._results) - 1
 
-    def _throbber_callback(self, string):
-        self._throbber_string = string
+    def _activity_indicator_callback(self, string):
+        self._activity_indicator_string = string
         get_app().invalidate()
 
     def _get_text_fragments(self):
         if self.is_searching:
-            return [('class:dialog.search.results', self._throbber_string)]
+            return [('class:dialog.search.results', self._activity_indicator_string)]
         elif not self._results:
             return 'No results'
 
