@@ -34,7 +34,7 @@ class TextField:
         self._text = text
         self._width = width
         self._height = height
-        self._throbber = utils.Throbber(callback=self.set_text)
+        self._activity_indicator = utils.ActivityIndicator(callback=self.set_text)
         self.container = Window(
             content=FormattedTextControl(lambda: self.text),
             width=width,
@@ -61,26 +61,33 @@ class TextField:
             else:
                 height = None
 
-            # prompt_toolkit has no support for word wrapping.
-            paragraphs = text.split('\n')
-            self._text = '\n\n'.join(textwrap.fill(
-                paragraph,
-                width=width,
-                max_lines=height,
-                placeholder='…',
-            ) for paragraph in paragraphs)
+            if height == 1:
+                # Remove newlines. Don't do word wrapping to avoid replacing
+                # long words with "…" with lots of available free space.
+                self._text = text.replace('\n', ' ')
+            else:
+                # prompt_toolkit has no support for word wrapping.
+                paragraphs = text.split('\n')
+                self._text = '\n\n'.join(textwrap.fill(
+                    paragraph,
+                    width=width,
+                    max_lines=height,
+                    placeholder='…',
+                ) for paragraph in paragraphs)
+
         else:
             self._text = text
+
         get_app().invalidate()
 
     @property
     def is_loading(self):
         """Whether an activity indicator is displayed"""
-        return self._throbber.active
+        return self._activity_indicator.active
 
     @is_loading.setter
     def is_loading(self, is_loading):
-        self._throbber.active = is_loading
+        self._activity_indicator.active = is_loading
 
     def __pt_container__(self):
         return self.container
@@ -91,7 +98,7 @@ class InputField:
 
     def __init__(self, text='', width=None, extend_width=True, read_only=False,
                  on_accepted=None, on_changed=None, style=''):
-        self._throbber = utils.Throbber(callback=self.set_text)
+        self._activity_indicator = utils.ActivityIndicator(callback=self.set_text)
         self.read_only = read_only
         self.on_accepted = on_accepted
         self.buffer = Buffer(
@@ -148,11 +155,11 @@ class InputField:
     @property
     def is_loading(self):
         """Whether an activity indicator is displayed"""
-        return self._throbber.active
+        return self._activity_indicator.active
 
     @is_loading.setter
     def is_loading(self, is_loading):
-        self._throbber.active = is_loading
+        self._activity_indicator.active = is_loading
 
     def __pt_container__(self):
         return self.container
