@@ -2,10 +2,9 @@
 Open a URL in a web browser
 """
 
-import asyncio
 import functools
 
-from . import LazyModule
+from . import LazyModule, get_aioloop
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -17,5 +16,5 @@ def open(url):
     """Attempt to open URL in default web browser"""
     # Don't block while the browser is being started
     wrapper = functools.partial(webbrowser.open_new_tab, str(url))
-    loop = asyncio.get_event_loop()
+    loop = get_aioloop()
     loop.run_in_executor(None, wrapper)
