@@ -13,7 +13,6 @@ from . import LazyModule, os_family, types
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
-tempfile = LazyModule(module='tempfile', namespace=globals())
 natsort = LazyModule(module='natsort', namespace=globals())
 
 
@@ -74,37 +73,42 @@ def limit_directory_size(path, max_total_size, min_age=None, max_age=None):
     :param max_total_size: Maximum combined size of all files in `path` and its
         subdirectories
     :param min_age: Preserve files that are younger than this
-    :type min_age: int or float
+    :type min_age: Unix timestamp
     :param max_age: Preserve files that are older than this
-    :type max_age: int or float
+    :type max_age: Unix timestamp
     """
+    @functools.lru_cache(maxsize=None)
+    def cached_file_size(f):
+        return file_size(f)
+
     def combined_size(filepaths):
-        return sum(file_size(f) for f in filepaths
+        return sum(cached_file_size(f) for f in filepaths
                    if os.path.exists(f) and not os.path.islink(f))
 
     # This should return mtime if file system was mounted with noatime.
     def atime(filepath):
-        statinfo = os.stat(filepath, follow_symlinks=False)
-        return statinfo.st_atime
+        try:
+            return os.stat(filepath, follow_symlinks=False).st_atime
+        except OSError:
+            return 0
 
     def get_filepaths(dirpath):
         return file_list(dirpath, min_age=min_age, max_age=max_age, follow_dirlinks=False)
 
-    # Keep removing oldest file until `path` size is small enough
+    # How much space do we have to free up?
     filepaths = get_filepaths(path)
-    while combined_size(filepaths) > max_total_size:
-        oldest_file = sorted(filepaths, key=atime)[0]
-        try:
-            os.unlink(oldest_file)
-        except OSError as e:
-            if e.strerror:
-                raise RuntimeError(f'{oldest_file}: Failed to prune: {e.strerror}')
-            else:
-                raise RuntimeError(f'{oldest_file}: Failed to prune: {e}')
-        else:
-            filepaths = get_filepaths(path)
+    total_size = combined_size(filepaths)
+    size_diff = total_size - max_total_size
+    if size_diff > 0:
+        # Collect old files until they free up enough space when removed
+        oldest_files = sorted(filepaths, key=atime)
+        files_to_remove = [oldest_files.pop(0)]
+        while combined_size(files_to_remove) < size_diff:
+            files_to_remove.append(oldest_files.pop(0))
 
-    prune_empty(path, files=True, directories=True)
+        # Actually remove the files
+        for file_to_remove in files_to_remove:
+            os.unlink(file_to_remove)
 
 
 def prune_empty(path, files=False, directories=True):
@@ -351,9 +355,13 @@ def file_list(path, extensions=(), min_age=None, max_age=None, follow_dirlinks=F
         return not extensions or file_extension(filename).casefold() in extensions
 
     def age_ok(filepath, now=time.time()):
-        statinfo = os.stat(filepath, follow_symlinks=False)
-        age = round(now - statinfo.st_atime)
-        return (min_age or age) <= age <= (max_age or age)
+        try:
+            statinfo = os.stat(filepath, follow_symlinks=False)
+        except OSError:
+            return False
+        else:
+            age = round(now - statinfo.st_atime)
+            return (min_age or age) <= age <= (max_age or age)
 
     if not path:
         # Handle any false value, e.g. "" or `None`
