@@ -8,7 +8,7 @@ import copy
 import os
 
 from ... import __project_name__, constants, errors
-from .. import fs, image
+from .. import configfiles, fs, image
 from . import common
 
 import logging  # isort:skip
@@ -20,7 +20,7 @@ class ImageHostBase(abc.ABC):
     Base class for image uploaders
 
     :param str cache_directory: Where to cache URLs; defaults to
-        :attr:`.constants.CACHE_DIRPATH`
+        :attr:`.constants.DEFAULT_CACHE_DIRECTORY`
     :param options: User configuration options for this image host,
         e.g. authentication details, thumbnail size, etc
     :type options: :class:`dict`-like
@@ -31,7 +31,7 @@ class ImageHostBase(abc.ABC):
         self._options.update()
         if options is not None:
             self._options.update(options)
-        self.cache_directory = cache_directory if cache_directory else constants.CACHE_DIRPATH
+        self._cache_dir = cache_directory if cache_directory else constants.DEFAULT_CACHE_DIRECTORY
 
     def __init_subclass__(cls, **kwargs):
         super().__init_subclass__(**kwargs)
@@ -69,7 +69,13 @@ class ImageHostBase(abc.ABC):
         return self._options
 
     default_config_common = {
-        'thumb_width': 0,  # No thumbnail
+        'thumb_width': configfiles.config_value(
+            value=0,
+            description=(
+                'Thumbnail width in pixels or 0 for no thumbnail. '
+                'Trackers may ignore this option and use a hardcoded thumbnail width.'
+            ),
+        ),
     }
     """Default user configuration for all subclasses"""
 
