@@ -148,8 +148,14 @@ class SceneQuery:
         episodes = tuple(episode
                          for episodes in release.get('episodes', {}).values()
                          for episode in episodes)
-        if len(seasons) == 1 and len(episodes) == 1:
-            keywords.append(f'S{int(seasons[0]):02d}E{int(episodes[0]):02d}')
+        if len(seasons) == 1 and len(episodes) == 1 and seasons[0] and episodes[0]:
+            try:
+                season = int(seasons[0])
+                episode = int(episodes[0])
+            except (ValueError, TypeError):
+                pass
+            else:
+                keywords.append(f'S{season:02d}E{episode:02d}')
 
         query = cls(
             *keywords,
@@ -201,7 +207,7 @@ class SceneQuery:
             `(keywords, group)` that returns a sequence of release names
         :param bool only_existing_releases: If this is truthy (the default), the
             results contain all episodes for every season pack in
-            :attr:`keywords`.  Otherwise, fake season pack release names are
+            :attr:`keywords`. Otherwise, fake season pack release names are
             included in the returned results.
         """
         if only_existing_releases is None:
