@@ -37,6 +37,9 @@ class Query:
     }
 
     def __init__(self, title='', **kwargs):
+        for k in kwargs:
+            if k not in self._kwarg_defaults:
+                raise TypeError(f'Unkown argument: {k!r}')
         self._kwargs_order = tuple(kwargs)
         self._signal = signal.Signal()
         self._signal.add('changed')
@@ -134,6 +137,21 @@ class Query:
         if str(self) != before:
             self.signal.emit('changed', self)
 
+    def copy(self, **updates):
+        """
+        Return new :class:`Query` instance with updated attributes
+
+        :param updates: Updated attributes
+        """
+        kwargs = {
+            'title': self.title,
+            'type': self.type,
+            'year': self.year,
+            'id': self.id,
+        }
+        kwargs.update(updates)
+        return type(self)(**kwargs)
+
     _types = {
         ReleaseType.movie: ('movie', 'film'),
         ReleaseType.season: ('season', 'series', 'tv', 'show', 'tvshow'),
@@ -321,3 +339,9 @@ class Person(str):
         obj = super().__new__(cls, name)
         obj.url = url
         return obj
+
+    def __repr__(self):
+        args = repr(str(self))
+        if self.url:
+            args += f', url={self.url}'
+        return f'{type(self).__name__}({args})'
